@@ -10,11 +10,19 @@ case ${SYSTEM} in
         ;;
     Linux*)
         ARCH=`which arch`
-	if [ -x $ARCH ]; then
-	    ARCHITECTURE=`arch`
-	else
+	    if [ -x $ARCH ]; then
+	        ARCHITECTURE=`arch`
+	    else
             ARCHITECTURE=`uname -p | tr "\ " "-"`
-	fi
+	    fi
+        ;;
+    OpenBSD*)
+        ARCH=`which arch`
+        if [ -x $ARCH ]; then
+           ARCHITECTURE=`arch -s`
+        else
+           ARCHITECTURE=`uname -p | tr "\ " "-"`
+        fi
         ;;
     *)
         ARCHITECTURE=`uname -p`
