@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -523,7 +523,7 @@ osi_bool osi_get_next_file( OSI_DIRECTORY *directory )
 
 #ifndef WIN32
 
-struct dirent * osi_readdir( OSI_DIRECTORY *d )
+struct dirent *osi_readdir( OSI_DIRECTORY *d )
 {
 #if defined(HAVE_GETDIRENTRIES) || defined(HAVE_GETDENTS)
 
@@ -534,9 +534,15 @@ struct dirent * osi_readdir( OSI_DIRECTORY *d )
         return NULL;
     }
 
-    for(;;)
+    do
     {
-        if( d->dd_loc == 0 )
+        /*
+         * We want to fetch new dirents if either:
+         * 1. This is our first read of the directory
+         * 2. We've reached the end of a previous fetch for this directory
+         *    and there might be more dirents to fetch
+         */
+        if( d->dd_loc >= d->dd_size )
         {
         #ifdef HAVE_GETDIRENTRIES
             d->dd_size = getdirentries( d->dd_fd, d->buffer,
@@ -545,46 +551,39 @@ struct dirent * osi_readdir( OSI_DIRECTORY *d )
             d->dd_size = getdents( d->dd_fd, (struct dirent *)d->buffer,
                                    d->dd_len );
         #endif
+
+            if( d->dd_size <= 0  )
+            {
+                return NULL;
+            }
+
+            d->dd_loc = 0;    /* Reset if this is a secondary fetch */
         }
 
-        if( d->dd_size <= 0  )
-        {
-            return NULL;
-        }
-
-        dp = (struct dirent *)(d->buffer + d->dd_loc );
+        dp = (struct dirent *)(d->buffer + d->dd_loc);
 
         if( dp == NULL )
         {
             return NULL;
         }
 
-        if( dp->d_reclen <= 0 || dp->d_reclen > d->dd_len + 1 - d->dd_loc )
-        {
-            return NULL;
-        }
-
         d->dd_loc += dp->d_reclen;
 
-        /* this causes a crash on irix, alignment?  not sure yet. */
-
 #ifndef SYSTEM_IRIX
-        if( dp->d_ino == 0 )
-        {
-            continue;
-        }
+    } while( dp->d_ino == 0 );    /* Skip deleted entries */
+#else
+    } while ( 1 );
 #endif
 
-        d->file = dp;
+    d->file = dp;
 
-        if( d->file->d_name[0] == '\0' )
-        {
-            return NULL;
-        }
-
-        return dp;
+    if( d->file->d_name[0] == '\0' )
+    {
+        return NULL;
     }
 
+    return dp;
+
 #endif /* HAVE_GETDIRENTRIES */
 
     return NULL;
