@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -76,6 +76,7 @@ struct e_keywords error_keywords[] =
     { "no database specified.", OSI_ERROR_NO_DB_SPECIFIED },
     { "no filters", OSI_ERROR_NO_FILTERS },
     { "unable to read notification filters.", OSI_ERROR_READ_FILTERS_FAILED },
+    { "unable to push scan configuration.", OSI_ERROR_PUSH_CONFIG_FAILED },
 
     { "no hosts.", OSI_ERROR_NO_HOSTS },
 
@@ -115,6 +116,7 @@ struct e_keywords error_keywords[] =
     { "invalid path", OSI_ERROR_INVALID_PATH },
     { "i/o error.", OSI_ERROR_IO_ERROR },
     { "file exists.", OSI_ERROR_FILE_EXISTS },
+    { "dir too deep.", OSI_ERROR_DIRECTORY_TOO_DEEP },
 
     { "unable to create file.", OSI_ERROR_UNABLE_TO_CREATE_FILE },
     { "unable to open directory.", OSI_ERROR_UNABLE_TO_OPEN_DIRECTORY },
