@@ -3805,7 +3805,22 @@ osi_bool ctl_get_database( CTL_CONTEXT *context )
                 }
                             
                 status = TRUE;
-                break;
+
+                /* This is a strange race condition fix... This code
+                 * is functionally equivalent to the previous code:
+                 * status = TRUE;
+                 * break;
+                 *
+                 * but on some systems that code would return FALSE.
+                 * A sleep(1) was proven to relieve the symptoms.
+                 * Instead, this looks like a better solution to me.
+                 */
+                if( dbfile )
+                {
+                    fclose( dbfile );
+                }
+       
+                return status;
             }
 
             /* drop all other message types. */
