@@ -111,7 +111,7 @@ int write_cmp_filters_to_file( osi_list filters, const char *path )
             fwrite( filter->exclude, sizeof(char),
                     strlen( filter->exclude ), file );
 
-            fwrite( "\n", sizeof(char), 1, file );
+            //fwrite( "\n", sizeof(char), 1, file );
         }
 
         head = list_get_next_node( head );
