@@ -59,6 +59,7 @@
 
 extern char config_file_path[MAX_PATH_LENGTH];
 extern char cmp_filter_db_path[MAX_PATH_LENGTH];
+extern char cmp_filter_file_path[MAX_PATH_LENGTH];
 
 extern SSL_CTX *ssl_context;
 
@@ -632,78 +633,57 @@ void process_get_cmp_filter_list( SSL *ssl, CONTROL_REQUEST *request )
     int result;
     int result_size;
 
-    int number_of_filters;
     int sequence = 0;
 
-    unsigned char buffer[sizeof(OSI_CMP_FILTER)];
+    char buffer[sizeof(OSI_CMP_FILTER)];
+    FILE *filters = NULL;
 
-    OSI_DB db;
+    MESSAGE message;
 
     if( ( request == NULL ) || ( ssl == NULL ) )
     {
         return;
     }
 
-    /* create path to the db to open. */
-
-    memset( &db, 0, sizeof( db ) );
-    osi_strlcpy( db.path, cmp_filter_db_path, sizeof( db.path ) );
-
-    result = osi_db_open( &db, OSI_DB_READ );
-
-    if( result != OSI_DB_OK )
+    if( ( filters = osi_fopen( cmp_filter_file_path, "r", 0 ) ) == NULL )
     {
-        osi_ssl_write_error_message( OSI_ERROR_DB_OPEN_FAILED,
-                                     "unable to open filter database.", ssl );
+        osi_ssl_write_error_message( OSI_ERROR_FILE_NOT_FOUND,
+                                     "log file does not exist.", ssl );
 
         return;
     }
 
-    /* find number of errors in this database. */
-
-    number_of_filters = osi_db_get_record_count( &db );
-
-    if( number_of_filters <= 0 )
+    memset( buffer, 0, sizeof( buffer ) );
+    while( fgets( buffer, sizeof( buffer ), filters ) != NULL )
     {
-        osi_ssl_write_error_message( OSI_ERROR_DB_NO_FILTERS,
-                                     "filter database is empty.", ssl );
 
-        return;
-    }
+        initialize_message( &message, MESSAGE_TYPE_CONTROL_DATA );
 
-    result = osi_db_get_first_record( &db, buffer, sizeof( buffer ),
-                                      &result_size );
-
-    while( result == OSI_DB_OK )
-    {
-        MESSAGE message;
-
-        /* send this out in a message, if we are sending the */
-        /* last message, put it in a CONTROL_DATA_LAST type. */
-
-        if( ( sequence + 1 ) < number_of_filters )
-        {
-            initialize_message( &message, MESSAGE_TYPE_CONTROL_DATA );
-        }
-
-        else
-        {
-            initialize_message( &message, MESSAGE_TYPE_CONTROL_DATA_LAST );
-        }
-
-        result = message_set_payload( &message, buffer, result_size, sequence );
+        result = message_set_payload( &message, buffer, (sizeof( buffer ) ),
+                                      sequence );
 
         if( result == MESSAGE_OK )
         {
             osi_ssl_write_message( &message, ssl );
+            sequence++;
         }
 
+        memset( buffer, 0, sizeof( buffer ) );
+    }
+    memset( buffer, 0, sizeof( buffer ) );
+
+    initialize_message( &message, MESSAGE_TYPE_CONTROL_DATA_LAST );
+    result = message_set_payload( &message, buffer, (sizeof( buffer ) ),
+        sequence );
+
+    if( result == MESSAGE_OK )
+    {
+        osi_ssl_write_message( &message, ssl );
         sequence++;
-        result = osi_db_get_next_record( &db, buffer, sizeof( buffer ),
-                                         &result_size );
     }
 
-    osi_db_close( &db );
+    fclose( filters );
+
 }
 
 void process_save_cmp_filter_list( SSL *ssl, CONTROL_REQUEST *request )
@@ -715,6 +695,7 @@ void process_save_cmp_filter_list( SSL *ssl, CONTROL_REQUEST *request )
     fd_set read_set;
 
     OSI_DB db;
+    FILE *filters = NULL;
 
     if( ( request == NULL ) || ( ssl == NULL ) )
     {
@@ -724,6 +705,15 @@ void process_save_cmp_filter_list( SSL *ssl, CONTROL_REQUEST *request )
     memset( &db, 0, sizeof( db ) );
     osi_strlcpy( db.path, cmp_filter_db_path, sizeof( db.path ) );
 
+
+    filters = osi_fopen( cmp_filter_file_path, "w+", OSI_DEFAULT_PERMISSIONS );
+    if( filters == NULL )
+    {
+        osi_print_stderr( "unable to open filter flat file for write (%s)",
+            cmp_filter_file_path );
+        return;
+    }
+
     result = osi_db_open( &db, OSI_DB_WRITE );
 
     if( result != OSI_DB_OK )
@@ -783,6 +773,8 @@ void process_save_cmp_filter_list( SSL *ssl, CONTROL_REQUEST *request )
 
                     if( ( filter != NULL ) && ( size > 0 ) )
                     {
+                        fwrite( filter->exclude, sizeof( char ), strlen( filter->exclude ), filters );
+                        fwrite( "\n", sizeof( char ), 1, filters );
                         osi_db_store_record( &db, filter, (int)size );
                     }
 
@@ -792,6 +784,8 @@ void process_save_cmp_filter_list( SSL *ssl, CONTROL_REQUEST *request )
 
                     if( ( filter != NULL ) && ( size > 0 ) )
                     {
+                        fwrite( filter->exclude, sizeof( char ), strlen( filter->exclude ), filters );
+                        fwrite( "\n", sizeof( char ), 1, filters );
                         osi_db_store_record( &db, filter, (int)size );
                     }
 
@@ -814,6 +808,7 @@ void process_save_cmp_filter_list( SSL *ssl, CONTROL_REQUEST *request )
     }
 
 exit_gracefully:
+    fclose( filters );
     osi_db_close( &db );
 }
 
