@@ -160,3 +160,51 @@ osi_bool md_filter_close_database( OSI_DB *filter_db )
 
     return FALSE;
 }
+
+/*
+ * Create the filter flat file, this file is used for the
+ * master copy of the filter rules.  It is read from before
+ * editing and written to after editing.  The filter db is
+ * generated using this file.
+ */
+osi_bool md_filter_create_file( const char *filter_file )
+{
+    OSI_DB filter_db;
+    OSI_CMP_FILTER filter;
+    FILE *filters = NULL;
+    int result;
+    int result_size;
+
+    unsigned char buffer[sizeof(OSI_CMP_FILTER)];
+
+    /* Open the filter database */
+    if( md_filter_open_database( &filter_db ) == FALSE )
+    {
+        osi_print_stderr( "unable to open filter database in md_filter_create_file" );
+        return FALSE;
+    }
+
+    /* Open the filters file for writing, read in each of the database entries
+     * and dump them into the file one by one
+     */
+    filters = osi_fopen( filter_file, "w+", OSI_DEFAULT_PERMISSIONS );
+    if( filters == NULL )
+    {
+        osi_print_stderr( "unable to open filter flat file for write (%s)",
+            filter_file );
+        return FALSE;
+    }
+
+    result = osi_db_get_first_record( &filter_db, buffer, sizeof( buffer ), &result_size );
+
+    while( result == OSI_DB_OK )
+    {
+        unpack_cmp_filter( &filter, buffer, sizeof( buffer ) );
+        fwrite( filter.exclude, sizeof( char ), strlen( filter.exclude ), filters );
+        fwrite( "\n", sizeof( char ), 1, filters );
+        result = osi_db_get_next_record( &filter_db, buffer, sizeof( buffer ), &result_size );
+    }
+
+    fclose( filters );
+    return TRUE;
+}
