@@ -259,7 +259,6 @@ void process()
     {
         client_length = sizeof( client );
 
-        check_for_signals();
         wait_for_data();
 
         /* we have data waiting, see if it is to the server.  if it */
@@ -388,6 +387,22 @@ void initialize_root_path()
 
     osi_strlcat( cmp_filter_db_path, NOTIFY_FILTER_DB_NAME,
                  sizeof( cmp_filter_db_path ) );
+
+    /* Add in cmp_filter_file_path */
+    osi_strlcpy( cmp_filter_file_path, root_path,
+                 sizeof( cmp_filter_file_path ) );
+
+    osi_strlcat( cmp_filter_file_path, path_separator,
+                 sizeof( cmp_filter_file_path ) );
+
+    osi_strlcat( cmp_filter_file_path, NOTIFY_FILTER_FILE_NAME,
+                 sizeof( cmp_filter_file_path ) );
+
+}
+
+/******************************************************************************
+**
+**    Function: verify_root_directory
 }
 
 /******************************************************************************
@@ -558,7 +573,6 @@ void verify_root_directory()
     }
 
     /* now verify that we have a compare filter database. */
-
     if( osi_file_exists( cmp_filter_db_path ) == FALSE )
     {
         log_warning( LOG_ID_DAEMON_INFO, NULL,
@@ -573,6 +587,21 @@ void verify_root_directory()
             halt( EXIT_CODE_ERROR );
         }
     }
+    /* Check to see if the filter file exists.
+     * If it does not, dump the contents of the filter_db into it
+     */
+    if( osi_file_exists( cmp_filter_file_path ) == FALSE )
+    {
+        log_warning( LOG_ID_DAEMON_INFO, NULL,
+            "filter flatfile absent, creating one." );
+
+        if( md_filter_create_file( cmp_filter_file_path ) == FALSE )
+        {
+            osi_print_stderr("unable to create compare filter flatfile in (%s)",
+                cmp_filter_file_path );
+	    halt( EXIT_CODE_ERROR );
+        }
+    }
 
     log_info( LOG_ID_DAEMON_INFO, NULL, "using root directory: %s.",root_path );
 }
@@ -1423,6 +1452,8 @@ void wait_for_data()
 
 wait_start:
 
+    check_for_signals();
+
     FD_ZERO( &read_set );
 
     /* add the control socket to the set. */
@@ -1454,7 +1485,6 @@ wait_start:
 
     if( ( sresult < 0 ) && ( errno == EINTR ) )
     {
-        check_for_signals();
         goto wait_start;
     }
 }
@@ -1762,37 +1792,34 @@ void check_for_signals()
 
         child_pid = wait(&status);
 
-/*
-        while( ( pid = waitpid( -1, &status, WNOHANG ) ) > 0 ||
-               ( ( pid < 0 ) && ( errno == EINTR ) ) )
-        ;
-*/
-
-        if( child_pid == scheduler_pid )
+        while ( ( child_pid = waitpid( -1, &status, WNOHANG ) ) > 0 )
         {
-            log_error( LOG_ID_DAEMON_INFO, NULL,
-                       "SIGCHLD, scheduler has terminated!" );
+               if ( child_pid == scheduler_pid )
+               {
+                   log_error( LOG_ID_DAEMON_INFO, NULL,
+                              "SIGCHLD, scheduler has terminated!" );
 
-            halt(EXIT_CODE_ERROR);
-        }
+                   halt(EXIT_CODE_ERROR);
+               }
 
-        else if ( child_pid == log_pid )
-        {
-            log_error( LOG_ID_DAEMON_INFO, NULL,
-                       "SIGCHLD, log application was terminated!" );
-        }
+               else if ( child_pid == log_pid )
+               {
+                   log_error( LOG_ID_DAEMON_INFO, NULL,
+                              "SIGCHLD, log application was terminated!" );
+               }
 
-        else if ( getpid() == scheduler_pid )
-        {
-            log_info( LOG_ID_SCHEDULER_INFO, NULL,
-                      "SIGCHLD, scheduler child process has terminated." );
-        }
+               else if ( getpid() == scheduler_pid )
+               {
+                   log_info( LOG_ID_SCHEDULER_INFO, NULL,
+                             "SIGCHLD, scheduler child process has terminated." );
+               }
 
-        else
-        {
-            log_info( LOG_ID_DAEMON_INFO, NULL,
-                      "SIGCHLD, client process has terminated." );
-        }
+               else
+               {
+                   log_info( LOG_ID_DAEMON_INFO, NULL,
+                             "SIGCHLD, client process has terminated." );
+               }
+         }
     }
 
     if( received_sigpipe )
